@@ -7,7 +7,7 @@ use Perl::Tidy;
 use Cwd;
 use File::Basename();
 
-our $VERSION = '0.15';
+our $VERSION = '0.17';
 
 our @mode;
 our $section;
@@ -34,6 +34,7 @@ sub __reset(){
     body => '',
     file => undef,
     css_url => '../style.css',
+    isAdvent => 1,
   );
   %blocks = (
     code => '',
@@ -161,29 +162,36 @@ sub _handle_element_end {
   my $mode = pop @mode;
   if( $element_name eq 'Document' ){
     die "footnote '$_' is not defined" for keys %footnotes;
+    my ($htmlTitle, $pageTitle) = $data{isAdvent}
+	? ( sprintf('%d Perl Advent Calendar: %s',map {defined($_)?$_:''} @data{qw/year title/}),
+		sprintf('<h1><a href="../">Perl Advent Calendar %d-12</a>-%02d</h1>'."\n".'<h2 align="center">%s</h2>',,map {defined($_)?$_:''} @data{qw/year day title/})  )
+	: ( $data{title}||'',
+		sprintf('<h1>%s</h1>',$data{title}||'')  )
+    ;
     my $fmt = <<'EOF';
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <!-- Generated by Pod::Advent %s (Pod::Simple %s, Perl::Tidy %s) on %04d-%02d-%02d %02d:%02d:%02d -->
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-<title>%d Perl Advent Calendar: %s</title>
+<title>%s</title>
 <link rel="stylesheet" href="%s" type="text/css" />
 %s
 </head>
 <body>
-<h1><a href="../">Perl Advent Calendar %d-12</a>-%02d</h1>
-<h2 align="center">%s</h2>
-<h3 align="center">by %s</h3>
+%s
+%s
 EOF
     my @d = (localtime)[5,4,3,2,1,0]; $d[1]++; $d[0]+=1900;
     my $fh = $parser->output_fh() || \*STDOUT;
     printf( $fh $fmt,
 	$Pod::Advent::VERSION, $Pod::Simple::VERSION, $Perl::Tidy::VERSION,
 	@d[0..5],
-	(map {defined($_)?$_:''} @data{qw/year title css_url/}),
+	$htmlTitle,
+	$data{css_url},
 	$data{file} ? qq{<link rel="alternate" type="text/plain" href="$data{file}" />} : "",
-	(map {defined($_)?$_:''} @data{qw/year day title author/}),
+	$pageTitle,
+	$data{author} ? qq{<h3 align="center">by $data{author}</h3>} : '',
     ) unless $BODY_ONLY;
     print $fh $data{body};
     if( $data{file} ){
@@ -364,7 +372,7 @@ Pod::Advent - POD Formatter for The Perl Advent Calendar
 
 =head1 VERSION
 
-Version 0.15
+Version 0.17
 
 =head1 GETTING STARTED
 
